# Fil_IO: simple file selection/reading/writing
This library supports you in simplified reading and writing multiple files

## Installation
The minimal required python version is `Python3.6`.
The easiest installation can be done by `pip3 install fil_io`.

## Getting started
Once installed, just `from fil_io import xls` the package and start using as simple as:
`data_sheet = xls.load_single_sheet(file_name, sheet_name)` 
For further guidance and help look at the documentation:

## Documentation

Please find the documentation here: [documentation](https://fil_io.readthedocs.io/en/latest/)

## Release Notes
Please find all release notes here: [release notes](https://fil_io.readthedocs.io/en/latest/release_notes.html)


## Requests & contribution
If you desire anything changed in the package, need another feature please just create an issue.

I am happy for everybody wanting to contribute. Simplest way is to start writing issues, forking the repository and contacting me ;)

